@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::CLI;
 
@@ -10,13 +8,13 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.13.1'; # VERSION
+our $VERSION = '1.14.0'; # VERSION
 
 use FindBin;
 use File::Basename qw(basename dirname);
-use Time::HiRes qw(gettimeofday tv_interval);
-use Cwd qw(getcwd);
-use List::Util qw(max);
+use Time::HiRes    qw(gettimeofday tv_interval);
+use Cwd            qw(getcwd);
+use List::Util     qw(max);
 use Text::Wrap;
 use Term::ReadKey;
 use Sort::Naturally;
@@ -69,7 +67,7 @@ sub __run__ {
   %opts = Rex::Args->getopts;
 
   if ( $opts{'Q'} ) {
-    my ( $stdout, $stderr );
+    my $stdout;
     open( my $newout, '>', \$stdout );
     select $newout;
     close(STDERR);
@@ -744,14 +742,11 @@ sub load_rexfile {
       }
     };
 
-    my ( $stdout, $stderr, $default_stderr );
-    open $default_stderr, ">&", STDERR;
-
-    # we close STDERR here because we don't want to see the
-    # normal perl error message on the screen. Instead we print
-    # the error message in the catch-if below.
-    local *STDERR;
-    open( STDERR, ">>", \$stderr );
+    # we don't want to see the
+    # normal perl warning message on the screen. Instead we print
+    # the warning message in the catch-if below
+    my @warnings;
+    local $SIG{__WARN__} = sub { push @warnings, $_[0] };
 
     # we can't use $rexfile here, because if the variable contains dots
     # the perl interpreter try to load the file directly without using @INC
@@ -761,13 +756,15 @@ sub load_rexfile {
     # update %INC so that we can later use it to find the rexfile
     $INC{"__Rexfile__.pm"} = $rexfile;
 
-    # reopen STDERR
-    open STDERR, ">&", $default_stderr;
-
-    if ($stderr) {
-      my @lines = split( $/, $stderr );
+    if (@warnings) {
       Rex::Logger::info( "You have some code warnings:", 'warn' );
-      Rex::Logger::info( "\t$_",                         'warn' ) for @lines;
+      for (@warnings) {
+        chomp;
+
+        my $message = _tidy_loading_message( $_, $rexfile );
+
+        Rex::Logger::info( "\t$message", 'warn' );
+      }
     }
 
     1;
@@ -777,19 +774,37 @@ sub load_rexfile {
     my $e = $@;
     chomp $e;
 
-    # remove the strange path to the Rexfile which exists because
-    # we load the Rexfile via our custom code block.
-    $e =~ s|/loader/[^/]+/||smg;
+    $e = _tidy_loading_message( $e, $rexfile );
 
-    my @lines = split( $/, $e );
+    my ( @error_lines, @debug_lines );
+
+    for my $line ( split $/, $e ) {
+      $line =~ m{CLI[.]pm[ ]line[ ]\d+}msx
+        ? push @debug_lines, $line
+        : push @error_lines, $line;
+    }
 
     Rex::Logger::info( "Compile time errors:", 'error' );
-    Rex::Logger::info( "\t$_",                 'error' ) for @lines;
+
+    for my $error_line (@error_lines) {
+      Rex::Logger::info( "\t$error_line", 'error' );
+    }
+
+    for my $debug_line (@debug_lines) {
+      Rex::Logger::debug("\t$debug_line");
+    }
 
     exit 1;
   }
 }
 
+sub _tidy_loading_message {
+  my ( $message, $rexfile ) = @_;
+
+  $message =~ s{/loader/[^/]+/__Rexfile__[.]pm}{$rexfile}gmsx;
+  return $message;
+}
+
 sub exit_rex {
   my ( $exit_code_override, $signal ) = @_;
 
