@@ -1,8 +1,6 @@
 
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -112,7 +110,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.13.3'; # VERSION
+our $VERSION = '1.14.0'; # VERSION
 
 require Rex::Exporter;
 use Rex::TaskList;
@@ -319,9 +317,6 @@ sub task {
     push( @_, "" );
   }
 
-  my $ref_to_tasks = qualify_to_ref( 'tasks', $class );
-  push( @{ *{$ref_to_tasks} }, { name => $task_name_save, code => $_[-2] } );
-
   $options->{'dont_register'} ||= $dont_register_tasks;
   my $task_o = Rex::TaskList->create()->create_task( $task_name, @_, $options );
 
@@ -1587,17 +1582,17 @@ sub last_command_output {
 This is a function to compare a string with some given options.
 
  task "mytask", "myserver", sub {
-   my $ntp_service = case operating_sytem, {
+   my $ntp_service = case operating_system, {
                  Debian  => "ntp",
                  default => "ntpd",
                };
 
-   my $ntp_service = case operating_sytem, {
+   my $ntp_service = case operating_system, {
                  qr{debian}i => "ntp",
                  default    => "ntpd",
                };
 
-   my $ntp_service = case operating_sytem, {
+   my $ntp_service = case operating_system, {
                  qr{debian}i => "ntp",
                  default    => sub { return "foo"; },
                };
@@ -1789,9 +1784,12 @@ sub evaluate_hostname {
   if ( $rule =~ m/,/ ) {
     @ret = _evaluate_hostname_list( $start, $rule, $end );
   }
-  else {
+  elsif ( $rule =~ m/[.]{2}/msx ) {
     @ret = _evaluate_hostname_range( $start, $rule, $end );
   }
+  else {
+    croak('Invalid hostgroup expression');
+  }
 
   return @ret;
 }
