@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -34,7 +32,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.0'; # VERSION
 
 #use Rex;
 
@@ -60,11 +58,6 @@ Setting this variable to 1 will enable debug logging.
 
 our $debug = 0;
 
-# we store the default handle to stderr
-# so that we can restore the handle inside the logging functions
-my $DEFAULT_STDERR;
-open $DEFAULT_STDERR, ">&", STDERR;
-
 =item $silent
 
 If you set this variable to 1 nothing will be logged.
@@ -125,9 +118,6 @@ sub info {
 
   return if $silent;
 
-  local *STDERR;
-  open STDERR, ">&", $DEFAULT_STDERR;
-
   if ( defined($type) ) {
     $msg = format_string( $msg, uc($type) );
   }
@@ -186,9 +176,6 @@ sub debug {
   return if $silent;
   return unless $debug;
 
-  local *STDERR;
-  open STDERR, ">&", $DEFAULT_STDERR;
-
   $msg = format_string( $msg, "DEBUG" );
 
   # workaround for windows Sys::Syslog behaviour on forks
