@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Pkg::Base;
 
@@ -13,7 +11,7 @@ use Rex::Helper::Run;
 use Rex::Interface::Exec;
 use Net::OpenSSH::ShellQuoter;
 
-our $VERSION = '1.13.1'; # VERSION
+our $VERSION = '1.14.0'; # VERSION
 
 sub new {
   my $that  = shift;
@@ -273,7 +271,9 @@ OLD_PKG:
   push @modifications, map { $_->{action} = 'installed'; $_ }
     grep { !exists $_->{found} } @new_installed;
 
-  map { delete $_->{found} } @modifications;
+  for (@modifications) {
+    delete $_->{found};
+  }
 
   return @modifications;
 }
