@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Pkg::Debian;
 
@@ -10,7 +8,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.13.1'; # VERSION
+our $VERSION = '1.14.0'; # VERSION
 
 use Rex::Helper::Run;
 use Rex::Commands::File;
@@ -118,7 +116,9 @@ OLD_PKG:
   push @modifications, map { $_->{action} = 'installed'; $_ }
     grep { !exists $_->{found} } @new_installed;
 
-  map { delete $_->{found} } @modifications;
+  for (@modifications) {
+    delete $_->{found};
+  }
 
   return @modifications;
 }
