@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -17,15 +15,15 @@ The Task Object. Typically you only need this class if you want to manipulate ta
  use Rex::Task;
  
  # create a new task
- my $task = Rex::Task->new(name => "testtask");
- $task->set_server("remoteserver");
- $task->set_code(sub { say "Hello"; });
- $task->modify("no_ssh", 1);
+ my $task = Rex::Task->new( name => 'testtask' );
+ $task->set_server('remoteserver');
+ $task->set_code( sub { say 'Hello'; } );
+ $task->modify( 'no_ssh', 1 );
  
  # retrieve an existing task
  use Rex::TaskList;
  
- my $existing_task = Rex::TaskList->get_task('my_task');
+ my $existing_task = Rex::TaskList->create->get_task('my_task');
 
 =head1 METHODS
 
@@ -39,7 +37,7 @@ use warnings;
 use Data::Dumper;
 use Time::HiRes qw(time);
 
-our $VERSION = '1.13.1'; # VERSION
+our $VERSION = '1.14.0'; # VERSION
 
 use Rex::Logger;
 use Rex::TaskList;
